#[non_exhaustive]pub enum NativeLifecycleEvent {
AndroidNotificationStop,
AndroidTimeout {
fgs_type: Option<String>,
},
}Expand description
Native platform lifecycle events sent from Kotlin/Swift to the Rust actor.
These events originate in the native layer and are forwarded to the actor
via ManagerCommand::NativeLifecycleEvent.
The actor maps each variant to the appropriate StopReason.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AndroidNotificationStop
User pressed stop on the Android foreground service notification.
AndroidTimeout
Android system killed the foreground service due to a timeout.
Implementations
Sourceimpl NativeLifecycleEvent
impl NativeLifecycleEvent
Sourcepub fn to_stop_reason(&self) -> StopReason
pub fn to_stop_reason(&self) -> StopReason
Map this native event to the corresponding StopReason.