#[non_exhaustive]pub struct PlatformCapabilities {
pub platform: Platform,
pub lifecycle_mode: LifecycleMode,
pub survives_app_close: LifecycleGuarantee,
pub survives_reboot: LifecycleGuarantee,
pub survives_force_quit: LifecycleGuarantee,
pub background_execution: LifecycleGuarantee,
pub limitations: Vec<String>,
pub required_setup: Vec<String>,
}Expand description
Platform-specific background execution capabilities.
Returned by the get_platform_capabilities Tauri command. Provides honest
reporting of what each platform can guarantee for background service survival.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.platform: Platformlifecycle_mode: LifecycleModesurvives_app_close: LifecycleGuaranteesurvives_reboot: LifecycleGuaranteesurvives_force_quit: LifecycleGuaranteebackground_execution: LifecycleGuaranteelimitations: Vec<String>required_setup: Vec<String>Trait Implementations
Sourceimpl Clone for PlatformCapabilities
impl Clone for PlatformCapabilities
Sourcefn clone(&self) -> PlatformCapabilities
fn clone(&self) -> PlatformCapabilities
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PlatformCapabilities
impl Debug for PlatformCapabilities
Sourceimpl<'de> Deserialize<'de> for PlatformCapabilities
impl<'de> Deserialize<'de> for PlatformCapabilities
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for PlatformCapabilities
impl PartialEq for PlatformCapabilities
Sourcefn eq(&self, other: &PlatformCapabilities) -> bool
fn eq(&self, other: &PlatformCapabilities) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PlatformCapabilities
impl Serialize for PlatformCapabilities
impl StructuralPartialEq for PlatformCapabilities