#[non_exhaustive]pub struct ValidationIssue {
pub severity: Severity,
pub code: String,
pub message: String,
pub fix: Option<String>,
pub platform: Platform,
}Expand description
A single validation issue found during lifecycle validation.
Each issue has a severity level, machine-readable code, human-readable message, optional fix suggestion, and the platform it applies to.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.severity: Severitycode: Stringmessage: Stringfix: Option<String>platform: PlatformTrait Implementations
Sourceimpl Clone for ValidationIssue
impl Clone for ValidationIssue
Sourcefn clone(&self) -> ValidationIssue
fn clone(&self) -> ValidationIssue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ValidationIssue
impl Debug for ValidationIssue
Sourceimpl<'de> Deserialize<'de> for ValidationIssue
impl<'de> Deserialize<'de> for ValidationIssue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ValidationIssue
impl PartialEq for ValidationIssue
Sourcefn eq(&self, other: &ValidationIssue) -> bool
fn eq(&self, other: &ValidationIssue) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ValidationIssue
impl Serialize for ValidationIssue
impl StructuralPartialEq for ValidationIssue