pub struct PersistentIpcClientHandle { /* private fields */ }Expand description
Handle to a persistent IPC client that maintains a long-lived connection to the headless sidecar.
The background task automatically:
- Relays
IpcEventframes toapp.emit("background-service://event", ...) - Reconnects on connection failure with exponential backoff (1s–30s, up to 10 retries)
- Forwards commands (start/stop/is_running) over the same connection
Implementations
Sourceimpl PersistentIpcClientHandle
impl PersistentIpcClientHandle
Sourcepub fn spawn<R: Runtime>(socket_path: PathBuf, app: AppHandle<R>) -> Self
pub fn spawn<R: Runtime>(socket_path: PathBuf, app: AppHandle<R>) -> Self
Spawn the persistent IPC client background task.
The task immediately begins trying to connect to the socket at
socket_path. Events are relayed to the Tauri event system via
app.emit().
Sourcepub async fn start(&self, config: StartConfig) -> Result<(), ServiceError>
pub async fn start(&self, config: StartConfig) -> Result<(), ServiceError>
Send a Start command through the persistent connection.
Sourcepub async fn stop(&self) -> Result<(), ServiceError>
pub async fn stop(&self) -> Result<(), ServiceError>
Send a Stop command through the persistent connection.
Sourcepub async fn is_running(&self) -> Result<bool, ServiceError>
pub async fn is_running(&self) -> Result<bool, ServiceError>
Query whether the service is running through the persistent connection.
Sourcepub async fn get_state(&self) -> Result<ServiceStatus, ServiceError>
pub async fn get_state(&self) -> Result<ServiceStatus, ServiceError>
Query the current service lifecycle state through the persistent connection.
Sourcepub fn is_connected(&self) -> bool
pub fn is_connected(&self) -> bool
Returns true if the persistent client is currently connected to the
headless sidecar, false otherwise.